@@ -1,6 +1,7 @@
 import json
 from typing import Optional
 
+from .image_model import ImageModel
 from .aiiohttp import AiohttpSession
 from .model import Model
 from .session import BaseSession
@@ -22,7 +23,7 @@ class AsyncOpenAI:
     def token(self) -> str:
         return self.__token
 
-    async def send_message(self, message, model: Model):
+    async def generate_message(self, message, model: Model):
         session = await self.session.create_session()
         url = self.session.api.api_url()
         headers = {'Content-Type': 'application/json', 'Authorization': 'Bearer ' + self.__token}
@@ -35,3 +36,17 @@ class AsyncOpenAI:
                 return await resp.json()
         finally:
             await session.close()
+
+    async def generate_image(self, message, model: ImageModel):
+        session = await self.session.create_session()
+        url = self.session.api.image_url() + '/generations'
+        headers = {'Content-Type': 'application/json', 'Authorization': 'Bearer ' + self.__token}
+        model.prompt = message
+
+        payload = json.dumps(model.__dict__)
+
+        try:
+            async with session.post(url, data=payload, headers=headers) as resp:
+                return await resp.json()
+        finally:
+            await session.close()
